@@ -357,51 +357,51 @@ class NBcategorical(object):
             category_ratio_df[column_name] = val_count
         return category_ratio_df.transpose().style.applymap(color_imbalanced)
 
-
-    @staticmethod
-    @_InputCheckCategorical.label_encoder_features_checker
-    def label_encoder_features(database, features_to_encode):
-        """
-        General Information
-        ----------
-        Encode features in the giving database using LabelEncoder() from sklearn.
-        Will preform encoding on all giving features and returns a dictionary with all the different
-        encoders where the ket is the feature name and the value is the LabelEncoder instance fitted
-        to that feature. Thus, the user is able to un-encode the feature when necessary.
-
-        Parameters
-        ----------
-        :param database: pandas Data Frame
-        First data set to check columns names from
-
-        :param features_to_encode: list or tuple of strings/int/float
-        The column names that the user wishes to encode.
-        All column names must be in the database and categorical/
-
-        :return:
-        returns a dictionary with all the different
-        encoders where the ket is the feature name and the value is the LabelEncoder instance fitted
-        to that feature. Thus, the user is able to un-encode the feature when necessary.
-
-        Raises
-        ------
-        ValueError : If input value not as mentioned above.
-
-        Exemples
-        -------
-        Will be added in version 0.2
-        """
-
-        label_encoder_dict = {}
-
-        for feat in features_to_encode:
-            le = LabelEncoder()
-
-            # fit the feature that we want to encode and tresform to numeric categories
-            database[feat] = le.fit_transform(database[feat])
-
-            print(f"for deature {feat} the categories are:\n", database[feat].value_counts().index)#todo:changeToConst
-
-            label_encoder_dict[feat] = le
-
-        return label_encoder_dict
+    # todo: debug
+    # @staticmethod
+    # @_InputCheckCategorical.label_encoder_features_checker
+    # def label_encoder_features(database, features_to_encode):
+    #     """
+    #     General Information
+    #     ----------
+    #     Encode features in the giving database using LabelEncoder() from sklearn.
+    #     Will preform encoding on all giving features and returns a dictionary with all the different
+    #     encoders where the ket is the feature name and the value is the LabelEncoder instance fitted
+    #     to that feature. Thus, the user is able to un-encode the feature when necessary.
+    #
+    #     Parameters
+    #     ----------
+    #     :param database: pandas Data Frame
+    #     First data set to check columns names from
+    #
+    #     :param features_to_encode: list or tuple of strings/int/float
+    #     The column names that the user wishes to encode.
+    #     All column names must be in the database and categorical/
+    #
+    #     :return:
+    #     returns a dictionary with all the different
+    #     encoders where the ket is the feature name and the value is the LabelEncoder instance fitted
+    #     to that feature. Thus, the user is able to un-encode the feature when necessary.
+    #
+    #     Raises
+    #     ------
+    #     ValueError : If input value not as mentioned above.
+    #
+    #     Exemples
+    #     -------
+    #     Will be added in version 0.2
+    #     """
+    #
+    #     label_encoder_dict = {}
+    #
+    #     for feat in features_to_encode:
+    #         le = LabelEncoder()
+    #
+    #         # fit the feature that we want to encode and tresform to numeric categories
+    #         database[feat] = le.fit_transform(database[feat])
+    #
+    #         print(f"for deature {feat} the categories are:\n", database[feat].value_counts().index)#todo:changeToConst
+    #
+    #         label_encoder_dict[feat] = le
+    #
+    #     return label_encoder_dict
